import os
import glob

from invoke import Collection, task

from . import py, docker, test


collections = [py, docker, test]

ns = Collection()
for c in collections:
    ns.add_collection(c)

ns.configure(dict(
    project='pyrkube',
    pwd=os.getcwd(),
    docker=dict(
        user=os.getenv('DOCKER_USER'),
        org=os.getenv('DOCKER_ORG', os.getenv('DOCKER_USER', 'telephoneorg')),
        tag='%s/%s:latest' % (
            os.getenv('DOCKER_ORG', os.getenv('DOCKER_USER', 'telephoneorg')),
            'pyrkube'
        )
    )
))



from invoke import task


@task
def mkvenv(ctx, project=None):
    ctx.run(
        "mkvirtualenv -a $PWD -r requirements.txt %s" % (project or ctx.project))
    print('\nRemember to execute: workon %s' % (project or ctx.project))


@task
def develop(ctx):
    ctx.run("python3 setup.py develop")


@task
def build(ctx):
    ctx.run("python3 setup.py sdist bdist_wheel")

@task
def upload(ctx):
    ctx.run("twine upload dist/*")


@task
def clean(ctx):
    ctx.run("rm -rf build dist *.egg-info")


@task(build, upload, clean)
def publish(ctx):
    pass



import os

from invoke import task


@task(default=True)
def build(ctx, tag=None):
    cmd = "docker build -t %s --force-rm ." % (tag or ctx.docker.tag)
    print('****    command: ', cmd)
    ctx.run(cmd)


@task
def rebuild(ctx, tag=None):
    ctx.run("docker build -t %s --pull --force-rm --no-cache ." % (tag or ctx.docker.tag))
